@@ -441,7 +441,9 @@ raptor_ntriples_term(raptor_parser* rdf_parser,
         break;
 
       default:
-        raptor_parser_error(rdf_parser, "Illegal string escape \\%c in \"%s\"", c, start);
+        raptor_parser_error(rdf_parser,
+                            "Illegal string escape \\%c in \"%s\"", c, 
+                            (char*)start);
         return 0;
     }
 
@@ -747,7 +749,7 @@ raptor_ntriples_parse_line(raptor_parser* rdf_parser,
             goto cleanup;
           }
           strcpy((char*)blank, (const char*)dest);
-          dest=raptor_generate_id(rdf_parser, 0, blank);
+          dest=raptor_parser_internal_generate_id(rdf_parser, 0, blank);
           terms_allocated[i]=1;
         }
 
