@@ -2,9 +2,7 @@
  *
  * raptor_general.c - Raptor general routines
  *
- * $Id: raptor_general.c,v 1.326 2006/01/02 07:19:59 cmdjb Exp $
- *
- * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2007, David Beckett http://purl.org/net/dajobe/
  * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
@@ -58,16 +56,51 @@ static void raptor_print_statement_part_as_ntriples(FILE* stream, const void *te
 static int raptor_initialised=0;
 
 
-const char * const raptor_short_copyright_string = "Copyright 2000-2006 David Beckett. Copyright 2000-2005 University of Bristol";
+const char * const raptor_short_copyright_string = "Copyright 2000-2007 David Beckett. Copyright 2000-2005 University of Bristol";
 
-const char * const raptor_copyright_string = "Copyright (C) 2000-2006 David Beckett - http://purl.org/net/dajobe/\nCopyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/";
+const char * const raptor_copyright_string = "Copyright (C) 2000-2007 David Beckett - http://purl.org/net/dajobe/\nCopyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/";
 
+const char * const raptor_license_string = "LGPL 2.1 or newer, GPL 2 or newer, Apache 2.0 or newer.\nSee http://librdf.org/raptor/LICENSE.html for full terms.";
+
+const char * const raptor_home_url_string = "http://librdf.org/raptor/";
+
+/**
+ * raptor_version_string:
+ *
+ * Library full version as a string.
+ *
+ * See also #raptor_version_decimal.
+ */
 const char * const raptor_version_string = VERSION;
 
+/**
+ * raptor_version_major:
+ *
+ * Library major version number as a decimal integer.
+ */
 const unsigned int raptor_version_major = RAPTOR_VERSION_MAJOR;
+
+/**
+ * raptor_version_minor:
+ *
+ * Library minor version number as a decimal integer.
+ */
 const unsigned int raptor_version_minor = RAPTOR_VERSION_MINOR;
+
+/**
+ * raptor_version_release:
+ *
+ * Library release version number as a decimal integer.
+ */
 const unsigned int raptor_version_release = RAPTOR_VERSION_RELEASE;
 
+/**
+ * raptor_version_decimal:
+ *
+ * Library full version as a decimal integer.
+ *
+ * See also #raptor_version_string.
+ */
 const unsigned int raptor_version_decimal = RAPTOR_VERSION_DECIMAL;
 
 
@@ -85,46 +118,11 @@ raptor_init(void)
   if(raptor_initialised)
     return;
 
-  raptor_init_sax2();
-  
-#ifdef RAPTOR_PARSER_GUESS
-  raptor_init_parser_guess();
-#endif
-#ifdef RAPTOR_PARSER_GRDDL
-  raptor_init_parser_grddl();
-#endif
-#ifdef RAPTOR_PARSER_RSS
-  raptor_init_parser_rss();
-#endif
-#ifdef RAPTOR_PARSER_TURTLE
-  raptor_init_parser_turtle();
-#endif
-#ifdef RAPTOR_PARSER_N3
-  raptor_init_parser_n3();
-#endif
-#ifdef RAPTOR_PARSER_NTRIPLES
-  raptor_init_parser_ntriples();
-#endif
-#ifdef RAPTOR_PARSER_RDFXML
-  raptor_init_parser_rdfxml();
-#endif
+  raptor_sax2_init();
 
-#ifdef RAPTOR_SERIALIZER_ATOM
-  raptor_init_serializer_atom();
-#endif
-#ifdef RAPTOR_SERIALIZER_RSS_1_0
-  raptor_init_serializer_rss10();
-#endif
-#ifdef RAPTOR_SERIALIZER_RDFXML
-  raptor_init_serializer_rdfxml();
-#endif
-#ifdef RAPTOR_SERIALIZER_RDFXML_ABBREV
-  raptor_init_serializer_rdfxmla();
-#endif
-#ifdef RAPTOR_SERIALIZER_NTRIPLES
-  raptor_init_serializer_ntriples();
-#endif
-  /* raptor_init_serializer_simple(); */
+  raptor_parsers_init();
+  
+  raptor_serializers_init();
 
   raptor_uri_init();
   raptor_www_init();
@@ -148,10 +146,12 @@ raptor_finish(void)
     return;
 
   raptor_www_finish();
-  raptor_delete_parser_factories();
-  raptor_delete_serializer_factories();
 
-  raptor_finish_sax2();
+  raptor_parsers_finish();
+
+  raptor_serializers_finish();
+
+  raptor_sax2_finish();
   
   raptor_initialised=0;
 }
@@ -283,18 +283,15 @@ raptor_statement_copy(const raptor_statement *statement) {
     strcpy((char*)new_blank, (const char*)statement->subject);
     s->subject=new_blank;
   } else if(statement->subject_type == RAPTOR_IDENTIFIER_TYPE_ORDINAL) {
-    int *new_ordinal=(int*)RAPTOR_MALLOC(int, sizeof(int));
-    *new_ordinal=*((int*)statement->subject);
-    s->subject=new_ordinal;
+    s->subject=raptor_new_uri_from_rdf_ordinal(*((int*)statement->subject));
+    s->subject_type=RAPTOR_IDENTIFIER_TYPE_RESOURCE;
   } else
     s->subject=raptor_uri_copy((raptor_uri*)statement->subject);
 
-  s->predicate_type=statement->predicate_type;
-  if(statement->predicate_type == RAPTOR_IDENTIFIER_TYPE_ORDINAL) {
-    int *new_ordinal=(int*)RAPTOR_MALLOC(int, sizeof(int));
-    *new_ordinal=*((int*)statement->predicate);
-    s->predicate=new_ordinal;
-  } else
+  s->predicate_type=RAPTOR_IDENTIFIER_TYPE_RESOURCE;
+  if(statement->predicate_type == RAPTOR_IDENTIFIER_TYPE_ORDINAL)
+    s->predicate=raptor_new_uri_from_rdf_ordinal(*((int*)statement->predicate));
+  else
     s->predicate=raptor_uri_copy((raptor_uri*)statement->predicate);
 
 
@@ -327,9 +324,8 @@ raptor_statement_copy(const raptor_statement *statement) {
     strcpy((char*)new_blank, (const char*)blank);
     s->object=new_blank;
   } else if(statement->object_type == RAPTOR_IDENTIFIER_TYPE_ORDINAL) {
-    int *new_ordinal=(int*)RAPTOR_MALLOC(int, sizeof(int));
-    *new_ordinal=*((int*)statement->object);
-    s->object=new_ordinal;
+    s->object=raptor_new_uri_from_rdf_ordinal(*((int*)statement->object));
+    s->object_type=RAPTOR_IDENTIFIER_TYPE_RESOURCE;
   } else {
     raptor_uri *uri=raptor_uri_copy((raptor_uri*)statement->object);
     s->object=uri;
@@ -812,6 +808,96 @@ raptor_check_ordinal(const unsigned char *name) {
 }
 
 
+/**
+ * raptor_invoke_simple_message_varargs:
+ * @type: string type "warning" or "error" for messages
+ * @handler: simple message handler
+ * @user_data; message handler data 
+ * @message: message format string and arguments
+ *
+ * Call message handler/data with varargs  - Internal
+ *
+ * Calls a function matching the raptor_simple_message_handler API but
+ * allows variable arguments
+ */
+void
+raptor_invoke_simple_message_varargs(const char *type,
+                                     raptor_simple_message_handler handler,
+                                     void* user_data, const char *message, 
+                                     va_list arguments)
+{
+  char *buffer;
+  size_t length;
+
+  buffer=raptor_vsnprintf(message, arguments);
+  if(!buffer) {
+    fprintf(stderr, "raptor_invoke_simple_message: Out of memory\n");
+    fprintf(stderr, "raptor %s - ", type);
+    vfprintf(stderr, message, arguments);
+    fputc('\n', stderr);
+  } else {
+    if(handler) {
+      length=strlen(buffer);
+      if(buffer[length-1]=='\n')
+        buffer[length-1]='\0';
+      handler(user_data, buffer);
+    } else {
+      fprintf(stderr, " raptor %s - ", type);
+      fputs(buffer, stderr);
+      fputc('\n', stderr);
+    }
+    RAPTOR_FREE(cstring, buffer);
+  }
+}
+
+
+/**
+ * raptor_invoke_message_varargs:
+ * @type: string type "warning" or "error" for messages
+ * @handler: simple message handler
+ * @user_data; message handler data 
+ * @locator: raptor_locator
+ * @message: message format string and arguments
+ *
+ * Call message handler/data with varargs  - Internal
+ *
+ * Calls a function matching the raptor_message_handler API but
+ * allows variable arguments
+ */
+void
+raptor_invoke_message_varargs(const char *type,
+                              raptor_message_handler handler,
+                              void* user_data, 
+                              raptor_locator* locator,
+                              const char *message, va_list arguments)
+{
+  char *buffer;
+  size_t length;
+
+  buffer=raptor_vsnprintf(message, arguments);
+  if(!buffer) {
+    fprintf(stderr, "raptor_invoke_message: Out of memory\n");
+    fprintf(stderr, "raptor %s - ", type);
+    vfprintf(stderr, message, arguments);
+    fputc('\n', stderr);
+  } else {
+    if(handler) {
+      length=strlen(buffer);
+      if(buffer[length-1]=='\n')
+        buffer[length-1]='\0';
+      handler(user_data, locator, buffer);
+    } else {
+      if(locator)
+        raptor_print_locator(stderr, locator);
+      fprintf(stderr, " raptor %s - ", type);
+      fputs(buffer, stderr);
+      fputc('\n', stderr);
+    }
+    RAPTOR_FREE(cstring, buffer);
+  }
+}
+
+
 /**
  * raptor_free_memory:
  * @ptr: memory pointer
@@ -847,7 +933,7 @@ raptor_free_memory(void *ptr)
  * that can be freed inside raptor either internally or via
  * raptor_free_memory.
  *
- * Examples include using this in the raptor_generate_id handler
+ * Examples include using this in the raptor_parser_generate_id() handler
  * code to create new strings that will be used internally
  * as short identifiers and freed later on by the parsers.
  *
@@ -874,7 +960,7 @@ raptor_alloc_memory(size_t size)
  * that can be freed inside raptor either internally or via
  * raptor_free_memory.
  *
- * Examples include using this in the raptor_generate_id handler
+ * Examples include using this in the raptor_parser_generate_id() handler
  * code to create new strings that will be used internally
  * as short identifiers and freed later on by the parsers.
  *
