@@ -167,8 +167,8 @@ void raptor_system_free(void *ptr);
 #define RAPTOR_FATAL2(msg,arg) do {fprintf(stderr, "%s:%d:%s: fatal error: " msg, __FILE__, __LINE__ , __func__, arg); abort();} while(0)
 #define RAPTOR_FATAL3(msg,arg1,arg2) do {fprintf(stderr, "%s:%d:%s: fatal error: " msg, __FILE__, __LINE__ , __func__, arg1, arg2); abort();} while(0)
 
-
-
+#define MAX_ASCII_INT_SIZE 13
+  
 /* XML parser includes */
 #ifdef RAPTOR_XML_EXPAT
 #ifdef HAVE_EXPAT_H
@@ -193,10 +193,10 @@ typedef struct raptor_sax2_s raptor_sax2;
 /* raptor_libxml.c exports */
 extern void raptor_libxml_init(raptor_sax2* sax2, raptor_uri *base_uri);
 extern void raptor_libxml_init_sax_error_handlers(xmlSAXHandler *sax);
-extern void raptor_libxml_init_generic_error_handlers(raptor_parser *rdf_parser);
+extern void raptor_libxml_init_generic_error_handlers(raptor_sax2 *sax2);
 
-extern void raptor_libxml_validation_error(void *context, const char *msg, ...);
-extern void raptor_libxml_validation_warning(void *context, const char *msg, ...);
+extern void raptor_libxml_validation_error(void *context, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+extern void raptor_libxml_validation_warning(void *context, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
 void raptor_libxml_free(xmlParserCtxtPtr xc);
 
 /* raptor_parse.c - exported to libxml part */
@@ -417,6 +417,20 @@ struct raptor_serializer_s {
    */
   raptor_uri* feature_start_uri;
 
+  /* FEATURES:
+   * non NULL to override default border color
+   */
+  unsigned char *feature_resource_border;
+  unsigned char *feature_literal_border;
+  unsigned char *feature_bnode_border;
+
+  /* FEATURES:
+   * non NULL to fill with value
+   */
+  unsigned char *feature_resource_fill;
+  unsigned char *feature_literal_fill;
+  unsigned char *feature_bnode_fill;
+
   void *error_user_data;
   void *warning_user_data;
 
@@ -504,7 +518,8 @@ void raptor_parser_factory_add_alias(raptor_parser_factory* factory, const char
 void raptor_parser_factory_add_mime_type(raptor_parser_factory* factory, const char* mime_type, int q);
 void raptor_parser_factory_add_uri(raptor_parser_factory* factory, const unsigned char *uri_string);
 
-unsigned char* raptor_generate_id(raptor_parser *rdf_parser, const int id_for_bag, unsigned char* user_bnodeid);
+unsigned char* raptor_parser_internal_generate_id(raptor_parser *rdf_parser, raptor_genid_type type, unsigned char *user_bnodeid);
+
 #ifdef RAPTOR_DEBUG
 void raptor_stats_print(raptor_parser *rdf_parser, FILE *stream);
 #endif
@@ -520,18 +535,18 @@ const char* raptor_parser_get_accept_header_all(void);
 int raptor_parse_uri_no_net_filter(void *user_data, raptor_uri* uri);
 
 /* raptor_general.c */
-void raptor_invoke_message_varargs(const char *type, raptor_message_handler handler, void* user_data, raptor_locator* locator, const char *message, va_list arguments);
-void raptor_invoke_simple_message_varargs(const char *type, raptor_simple_message_handler handler, void* user_data, const char *message, va_list arguments);
+void raptor_invoke_message_varargs(const char *type, raptor_message_handler handler, void* user_data, raptor_locator* locator, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(5, 0);
+void raptor_invoke_simple_message_varargs(const char *type, raptor_simple_message_handler handler, void* user_data, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(4, 0);
 
-extern void raptor_parser_fatal_error(raptor_parser* parser, const char *message, ...);
-extern void raptor_parser_error(raptor_parser* parser, const char *message, ...);
-extern void raptor_parser_simple_error(void* parser, const char *message, ...);
+extern void raptor_parser_fatal_error(raptor_parser* parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+extern void raptor_parser_error(raptor_parser* parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+extern void raptor_parser_simple_error(void* parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
 extern void raptor_parser_error_message_handler(void *user_data, raptor_locator* locator, const char *message);
-extern void raptor_parser_warning(raptor_parser* parser, const char *message, ...);
-extern void raptor_parser_fatal_error_varargs(raptor_parser* parser, const char *message, va_list arguments);
+extern void raptor_parser_warning(raptor_parser* parser, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+extern void raptor_parser_fatal_error_varargs(raptor_parser* parser, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(2, 0);
 extern void raptor_parser_fatal_error_message_handler(void *user_data, raptor_locator* locator, const char *message);
-extern void raptor_parser_error_varargs(raptor_parser* parser, const char *message, va_list arguments);
-extern void raptor_parser_warning_varargs(raptor_parser* parser, const char *message, va_list arguments);
+extern void raptor_parser_error_varargs(raptor_parser* parser, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(2, 0);
+extern void raptor_parser_warning_varargs(raptor_parser* parser, const char *message, va_list arguments)  RAPTOR_PRINTF_FORMAT(2, 0);
 void raptor_parser_warning_message_handler(void *user_data, raptor_locator* locator, const char *message);
 
 
@@ -632,6 +647,8 @@ void raptor_init_parser_grddl(void);
 void raptor_init_parser_guess(void);
 void raptor_init_parser_rss(void);
 
+void raptor_terminate_parser_grddl(void);
+
 /* raptor_parse.c */
 void raptor_parsers_init(void);
 void raptor_parsers_finish(void);
@@ -651,6 +668,7 @@ unsigned char* raptor_uri_detail_to_string(raptor_uri_detail *ud, size_t* len_p)
 /* serializers */
 void raptor_init_serializer_rdfxml(void);
 void raptor_init_serializer_ntriples(void);
+void raptor_init_serializer_dot(void);
 void raptor_init_serializer_simple(void);
 void raptor_delete_serializer_factories(void);
 
@@ -658,14 +676,17 @@ void raptor_delete_serializer_factories(void);
 void raptor_serializers_init(void);
 void raptor_serializers_finish(void);
 
-void raptor_serializer_error(raptor_serializer* serializer, const char *message, ...);
-void raptor_serializer_simple_error(void* serializer, const char *message, ...);
-void raptor_serializer_error_varargs(raptor_serializer* serializer, const char *message,  va_list arguments);
-void raptor_serializer_warning(raptor_serializer* serializer, const char *message, ...);
-void raptor_serializer_warning_varargs(raptor_serializer* serializer, const char *message, va_list arguments);
+void raptor_serializer_error(raptor_serializer* serializer, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+void raptor_serializer_simple_error(void* serializer, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+void raptor_serializer_error_varargs(raptor_serializer* serializer, const char *message,  va_list arguments) RAPTOR_PRINTF_FORMAT(2, 0);
+void raptor_serializer_warning(raptor_serializer* serializer, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+void raptor_serializer_warning_varargs(raptor_serializer* serializer, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(2, 0);
 
-/* raptor_serialize_rdfxml.c */  
+/* raptor_serialize_rdfxmla.c */  
 void raptor_init_serializer_rdfxmla(void);
+
+/* raptor_serialize_turtle.c */  
+void raptor_init_serializer_turtle(void);
   
 /* raptor_utf8.c */
 int raptor_unicode_is_namestartchar(long c);
@@ -746,8 +767,8 @@ void raptor_www_libxml_init(raptor_www *www);
 void raptor_www_libxml_free(raptor_www *www);
 int raptor_www_libxml_fetch(raptor_www *www);
 
-void raptor_www_error_varargs(raptor_www *www, const char *message, va_list arguments);
-void raptor_www_error(raptor_www *www, const char *message, ...);
+void raptor_www_error_varargs(raptor_www *www, const char *message, va_list arguments) RAPTOR_PRINTF_FORMAT(2, 0);
+void raptor_www_error(raptor_www *www, const char *message, ...) RAPTOR_PRINTF_FORMAT(2, 3);
 
 void raptor_www_curl_init(raptor_www *www);
 void raptor_www_curl_free(raptor_www *www);
@@ -783,7 +804,7 @@ struct raptor_xml_element_s {
   raptor_uri *base_uri;
 
   /* CDATA content of element and checks for mixed content */
-  unsigned char *content_cdata;
+  raptor_stringbuffer* content_cdata_sb;
   unsigned int content_cdata_length;
   /* how many cdata blocks seen */
   unsigned int content_cdata_seen;
@@ -1004,6 +1025,96 @@ int raptor_stringbuffer_append_turtle_string(raptor_stringbuffer* stringbuffer,
 /* raptor_xsd.c */
 raptor_identifier* raptor_new_identifier_from_double(double d);
 
+
+/* raptor_abbrev.c */
+
+typedef struct {
+  int ref_count;         /* count of references to this node */
+  int count_as_subject;  /* count of this blank/resource node as subject */
+  int count_as_object;   /* count of this blank/resource node as object */
+  
+  raptor_identifier_type type;  /* node type */
+  union {
+
+    struct {
+      raptor_uri *uri;
+    } resource;
+
+    struct {
+      unsigned char *string;
+      raptor_uri *datatype;
+      unsigned char *language;
+    } literal;
+
+    struct {
+      int ordinal;
+    } ordinal;
+
+    struct {
+      unsigned char *string;
+    } blank;
+    
+  } value;
+} raptor_abbrev_node;
+
+
+typedef struct {
+  raptor_abbrev_node* node;      /* node representing the subject of
+                                  * this resource */
+  raptor_abbrev_node* node_type; /* the rdf:type of this resource */
+  raptor_sequence *properties;   /* list of properties
+                                  * (predicate/object pair) of this
+                                  * subject */
+  raptor_sequence *list_items;   /* list of container elements if
+                                  * is rdf container */
+} raptor_abbrev_subject;
+
+
+raptor_abbrev_node* raptor_new_abbrev_node(raptor_identifier_type node_type, const void *node_data, raptor_uri *datatype, const unsigned char *language);
+void raptor_free_abbrev_node(raptor_abbrev_node* node);
+int raptor_abbrev_node_equals(raptor_abbrev_node* node1, raptor_abbrev_node* node2);
+int raptor_abbrev_node_matches(raptor_abbrev_node* node, raptor_identifier_type node_type, const void *node_data, raptor_uri *datatype, const unsigned char *language);
+raptor_abbrev_node* raptor_abbrev_node_lookup(raptor_sequence* nodes, raptor_identifier_type node_type, const void *node_value, raptor_uri *datatype, const unsigned char *language);
+
+raptor_abbrev_subject* raptor_new_abbrev_subject(raptor_abbrev_node* node);
+void raptor_free_abbrev_subject(raptor_abbrev_subject* subject);
+int raptor_abbrev_subject_add_property(raptor_abbrev_subject* subject, raptor_abbrev_node* predicate, raptor_abbrev_node* object);
+int raptor_abbrev_subject_add_list_element(raptor_abbrev_subject* subject, int ordinal, raptor_abbrev_node* object);
+raptor_abbrev_subject* raptor_abbrev_subject_find(raptor_sequence *sequence, raptor_identifier_type node_type, const void *node_data, int *idx);
+raptor_abbrev_subject* raptor_abbrev_subject_lookup(raptor_sequence* nodes, raptor_sequence* subjects, raptor_sequence* blanks, raptor_identifier_type node_type, const void *node_data);
+
+unsigned char *raptor_unique_id(unsigned char *base);
+
+raptor_qname* raptor_new_qname_from_resource(raptor_sequence* namespaces, raptor_namespace_stack* nstack, int* namespace_count, raptor_abbrev_node* node);
+
+
+/**
+ * raptor_turtle_writer:
+ *
+ * Raptor Turtle Writer class
+ */
+typedef struct raptor_turtle_writer_s raptor_turtle_writer;
+
+/* Turtle Writer Class (raptor_turtle_writer) */
+raptor_turtle_writer* raptor_new_turtle_writer(raptor_uri* base_uri, raptor_namespace_stack *nstack, raptor_uri_handler *uri_handler, void *uri_context, raptor_iostream* iostr, raptor_simple_message_handler error_handler, void *error_data);
+void raptor_free_turtle_writer(raptor_turtle_writer* turtle_writer);
+void raptor_turtle_writer_raw(raptor_turtle_writer* turtle_writer, const unsigned char *s);
+void raptor_turtle_writer_raw_counted(raptor_turtle_writer* turtle_writer, const unsigned char *s, unsigned int len);
+void raptor_turtle_writer_namespace_prefix(raptor_turtle_writer* turtle_writer, raptor_namespace* ns);
+void raptor_turtle_writer_increase_indent(raptor_turtle_writer *turtle_writer);
+void raptor_turtle_writer_decrease_indent(raptor_turtle_writer *turtle_writer);
+void raptor_turtle_writer_newline(raptor_turtle_writer *turtle_writer);
+void raptor_turtle_writer_reference(raptor_turtle_writer* turtle_writer, raptor_uri* uri);
+void raptor_turtle_writer_literal(raptor_turtle_writer* turtle_writer, unsigned char *s, unsigned char* lang, raptor_uri* datatype);
+void raptor_turtle_writer_qname(raptor_turtle_writer* turtle_writer, raptor_qname* qname);
+void raptor_turtle_writer_quoted(raptor_turtle_writer* turtle_writer, unsigned char *s);
+void raptor_turtle_writer_comment(raptor_turtle_writer* turtle_writer, const unsigned char *s);
+int raptor_turtle_writer_features_enumerate(const raptor_feature feature, const char **name,  raptor_uri **uri, const char **label);
+int raptor_turtle_writer_set_feature(raptor_turtle_writer *turtle_writer, raptor_feature feature, int value);
+int raptor_turtle_writer_set_feature_string(raptor_turtle_writer *turtle_writer, raptor_feature feature, const unsigned char *value);
+int raptor_turtle_writer_get_feature(raptor_turtle_writer *turtle_writer, raptor_feature feature);
+const unsigned char *raptor_turtle_writer_get_feature_string(raptor_turtle_writer *turtle_writer, raptor_feature feature);
+
 /* end of RAPTOR_INTERNAL */
 #endif
 
