@@ -51,9 +51,12 @@
 
 
 /* prototypes */
-static void raptor_libxml_warning(void *context, const char *msg, ...);
-static void raptor_libxml_error(void *context, const char *msg, ...);
-static void raptor_libxml_fatal_error(void *context, const char *msg, ...);
+static void raptor_libxml_warning(void* user_data, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+static void raptor_libxml_error_common(void* user_data, const char *msg, va_list args,  const char *prefix, int is_fatal) RAPTOR_PRINTF_FORMAT(2, 0);
+static void raptor_libxml_error(void *context, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+static void raptor_libxml_fatal_error(void *context, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+static void raptor_libxml_generic_error(void* user_data, const char *msg, ...) RAPTOR_PRINTF_FORMAT(2, 3);
+
 
 
 static const char* xml_warning_prefix="XML parser warning - ";
@@ -64,7 +67,7 @@ static const char* xml_validation_error_prefix="XML parser validation error - ";
 static const char* xml_validation_warning_prefix="XML parser validation warning - ";
 
 
-#ifdef RAPTOR_LIBXML_XMLSAX2INTERNALSUBSET
+#ifdef HAVE_XMLSAX2INTERNALSUBSET
 /* SAX2 - 2.6.0 or later */
 #define libxml2_internalSubset xmlSAX2InternalSubset
 #define libxml2_externalSubset xmlSAX2ExternalSubset
@@ -219,6 +222,9 @@ raptor_libxml_update_document_locator(raptor_sax2* sax2,
   if(xc && xc->inSubset)
     return;
 
+  if(!locator) 
+    return;
+  
   locator->line= -1;
   locator->column= -1;
 
@@ -234,6 +240,8 @@ raptor_libxml_update_document_locator(raptor_sax2* sax2,
 }
   
 
+static void raptor_libxml_call_handler(void *data, raptor_message_handler handler, raptor_locator* locator, const char *message,  va_list arguments) RAPTOR_PRINTF_FORMAT(4, 0);
+
 static void
 raptor_libxml_call_handler(void *data,
                            raptor_message_handler handler,
@@ -317,8 +325,9 @@ raptor_libxml_error_common(void* user_data, const char *msg, va_list args,
       /* user_data is not userData */
       sax2=(raptor_sax2*)((xmlParserCtxtPtr)user_data)->userData;
   }
-  
-  raptor_libxml_update_document_locator(sax2, sax2->locator);
+
+  if(sax2->locator)
+    raptor_libxml_update_document_locator(sax2, sax2->locator);
 
   length=prefix_length+strlen(msg)+1;
   nmsg=(char*)RAPTOR_MALLOC(cstring, length);
@@ -451,9 +460,9 @@ raptor_libxml_init(raptor_sax2* sax2, raptor_uri *base_uri)
   sax->ignorableWhitespace= raptor_sax2_cdata;
   sax->processingInstruction = NULL; /* processingInstruction */
   sax->comment = raptor_sax2_comment;      /* comment */
-  sax->warning=raptor_libxml_warning;
-  sax->error=raptor_libxml_error;
-  sax->fatalError=raptor_libxml_fatal_error;
+  sax->warning=(warningSAXFunc)raptor_libxml_warning;
+  sax->error=(errorSAXFunc)raptor_libxml_error;
+  sax->fatalError=(fatalErrorSAXFunc)raptor_libxml_fatal_error;
 
 #ifdef RAPTOR_LIBXML_XMLSAXHANDLER_EXTERNALSUBSET
   sax->externalSubset = raptor_libxml_externalSubset;
@@ -467,9 +476,9 @@ raptor_libxml_init(raptor_sax2* sax2, raptor_uri *base_uri)
 
 void
 raptor_libxml_init_sax_error_handlers(xmlSAXHandler *sax) {
-  sax->warning=raptor_libxml_warning;
-  sax->error=raptor_libxml_error;
-  sax->fatalError=raptor_libxml_fatal_error;
+  sax->warning=(warningSAXFunc)raptor_libxml_warning;
+  sax->error=(errorSAXFunc)raptor_libxml_error;
+  sax->fatalError=(fatalErrorSAXFunc)raptor_libxml_fatal_error;
 
 #ifdef RAPTOR_LIBXML_XMLSAXHANDLER_INITIALIZED
   sax->initialized = 1;
@@ -478,10 +487,10 @@ raptor_libxml_init_sax_error_handlers(xmlSAXHandler *sax) {
 
 
 void
-raptor_libxml_init_generic_error_handlers(raptor_parser *rdf_parser)
+raptor_libxml_init_generic_error_handlers(raptor_sax2 *sax2)
 {
-  xmlGenericError = raptor_libxml_generic_error;
-  xmlGenericErrorContext = rdf_parser;
+  xmlGenericError = (xmlGenericErrorFunc)raptor_libxml_generic_error;
+  xmlGenericErrorContext = sax2;
 }
 
 
