@@ -2,7 +2,7 @@
  *
  * raptor_parse.c - Parsers
  *
- * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2007, David Beckett http://purl.org/net/dajobe/
  * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
@@ -127,6 +127,9 @@ void
 raptor_parsers_finish(void)
 {
   raptor_free_sequence(parsers);
+#ifdef RAPTOR_PARSER_GRDDL
+  raptor_terminate_parser_grddl();
+#endif
   parsers=NULL;
 }
 
@@ -362,9 +365,6 @@ raptor_syntaxes_enumerate(const unsigned int counter,
 {
   raptor_parser_factory *factory;
 
-  if(counter < 0)
-    return 1;
-
   factory=(raptor_parser_factory*)raptor_sequence_get_at(parsers,
                                                          counter);
 
@@ -734,7 +734,7 @@ raptor_parse_uri_no_net_filter(void *user_data, raptor_uri* uri)
     return 0;
 
   raptor_parser_error((raptor_parser*)user_data, 
-                      "Network fetch of URI '%s' denied", uri);
+                      "Network fetch of URI '%s' denied", uri_string);
   return 1;
 }
 
@@ -902,8 +902,7 @@ raptor_parser_fatal_error_message_handler(void *user_data,
     abort();
   }
 
-  if(parser)
-    raptor_print_locator(stderr, locator);
+  raptor_print_locator(stderr, locator);
   fprintf(stderr, " raptor fatal error - ");
   fputs(message, stderr);
   fputc('\n', stderr);
@@ -989,8 +988,7 @@ raptor_parser_error_message_handler(void *user_data,
     return;
   }
 
-  if(parser)
-    raptor_print_locator(stderr, locator);
+  raptor_print_locator(stderr, locator);
   fprintf(stderr, " raptor error - ");
   fputs(message, stderr);
   fputc('\n', stderr);
@@ -1032,8 +1030,7 @@ raptor_parser_warning_message_handler(void *user_data,
     return;
   }
 
-  if(parser)
-    raptor_print_locator(stderr, locator);
+  raptor_print_locator(stderr, locator);
   fprintf(stderr, " raptor warning - ");
   fputs(message, stderr);
   fputc('\n', stderr);
@@ -1262,6 +1259,13 @@ raptor_set_feature(raptor_parser *parser, raptor_feature feature, int value)
     case RAPTOR_FEATURE_WRITER_INDENT_WIDTH:
     case RAPTOR_FEATURE_WRITER_XML_VERSION:
     case RAPTOR_FEATURE_WRITER_XML_DECLARATION:
+
+    case RAPTOR_FEATURE_RESOURCE_BORDER:
+    case RAPTOR_FEATURE_LITERAL_BORDER:
+    case RAPTOR_FEATURE_BNODE_BORDER:
+    case RAPTOR_FEATURE_RESOURCE_FILL:
+    case RAPTOR_FEATURE_LITERAL_FILL:
+    case RAPTOR_FEATURE_BNODE_FILL:
     default:
       return -1;
       break;
@@ -1336,6 +1340,12 @@ raptor_get_feature(raptor_parser *parser, raptor_feature feature)
     /* serializing features */
     case RAPTOR_FEATURE_RELATIVE_URIS:
     case RAPTOR_FEATURE_START_URI:
+    case RAPTOR_FEATURE_RESOURCE_BORDER:
+    case RAPTOR_FEATURE_LITERAL_BORDER:
+    case RAPTOR_FEATURE_BNODE_BORDER:
+    case RAPTOR_FEATURE_RESOURCE_FILL:
+    case RAPTOR_FEATURE_LITERAL_FILL:
+    case RAPTOR_FEATURE_BNODE_FILL:
 
     /* XML writer features */
     case RAPTOR_FEATURE_WRITER_AUTO_INDENT:
@@ -1415,13 +1425,13 @@ raptor_set_parser_strict(raptor_parser* rdf_parser, int is_strict)
  * The default algorithm uses both @prefix and @base to generate a new
  * identifier.   The exact identifier generated is not guaranteed to
  * be a strict concatenation of @prefix and @base but will use both
- * parts.
+ * parts. The @prefix parameter is copied to generate an ID.
  *
  * For finer control of the generated identifiers, use
  * raptor_set_default_generate_id_handler().
  *
- * If prefix is NULL, the default prefix is used (currently "genid")
- * If base is less than 1, it is initialised to 1.
+ * If @prefix is NULL, the default prefix is used (currently "genid")
+ * If @base is less than 1, it is initialised to 1.
  * 
  **/
 void
@@ -1582,15 +1592,34 @@ raptor_default_generate_id_handler(void *user_data, raptor_genid_type type,
 }
 
 
-/*
- * raptor_generate_id - Default generate id - internal
- */
-unsigned char *
-raptor_generate_id(raptor_parser *rdf_parser, const int id_for_bag,
-                   unsigned char *user_bnodeid)
+/**
+ * raptor_parser_generate_id:
+ * @rdf_parser: #raptor_parser parser object
+ * @type: Type of ID to generate
+ * 
+ * Generate an ID for a parser
+ *
+ * Type can be either RAPTOR_GENID_TYPE_BNODEID or
+ * RAPTOR_GENID_TYPE_BAGID
+ * 
+ * Return value: newly allocated generated ID or NULL on failure
+ **/
+unsigned char*
+raptor_parser_generate_id(raptor_parser *rdf_parser, raptor_genid_type type)
+{
+  if(type != RAPTOR_GENID_TYPE_BNODEID || 
+     type != RAPTOR_GENID_TYPE_BAGID)
+    return NULL;
+  
+  return raptor_parser_internal_generate_id(rdf_parser, type, NULL);
+}
+
+
+unsigned char*
+raptor_parser_internal_generate_id(raptor_parser *rdf_parser, 
+                                   raptor_genid_type type,
+                                   unsigned char *user_bnodeid)
 {
-  raptor_genid_type type=id_for_bag ? RAPTOR_GENID_TYPE_BNODEID :
-                                      RAPTOR_GENID_TYPE_BAGID;
   if(rdf_parser->generate_id_handler)
     return rdf_parser->generate_id_handler(rdf_parser->generate_id_handler_user_data,
                                            type, user_bnodeid);
@@ -1701,11 +1730,12 @@ raptor_guess_parser_name(raptor_uri *uri, const char *mime_type,
         if(!strcmp(mime_type, type_q->mime_type))
           break;
       }
+      /* got an exact match mime type - score it via the Q */
       if(type_q)
-        break;
+        score=type_q->q;
     }
-    /* got an exact match mime type - return result */
-    if(type_q)
+    /* mime type match has high Q - return result */
+    if(score >= 10)
       break;
     
     if(uri && factory->uri_string &&
@@ -1768,7 +1798,14 @@ raptor_parser_copy_user_state(raptor_parser *to_parser,
   to_parser->generate_id_handler_user_data= from_parser->generate_id_handler_user_data;
   to_parser->generate_id_handler= from_parser->generate_id_handler;
   to_parser->default_generate_id_handler_base= from_parser->default_generate_id_handler_base;
-  to_parser->default_generate_id_handler_prefix= from_parser->default_generate_id_handler_prefix;
+  /* copy over non-shared user state - generate ID prefix string */
+  if(from_parser->default_generate_id_handler_prefix) {
+    to_parser->default_generate_id_handler_prefix=RAPTOR_MALLOC(cstring,
+                    from_parser->default_generate_id_handler_prefix_length+1);
+    strncpy((char*)to_parser->default_generate_id_handler_prefix, 
+            (const char*)from_parser->default_generate_id_handler_prefix,
+            from_parser->default_generate_id_handler_prefix_length+1);
+  }
   to_parser->default_generate_id_handler_prefix_length= from_parser->default_generate_id_handler_prefix_length;
   to_parser->namespace_handler= from_parser->namespace_handler;
   to_parser->namespace_handler_user_data= from_parser->namespace_handler_user_data;
