@@ -524,7 +524,7 @@ raptor_rss_start_element_handler(void *user_data,
             rss_element->xml_writer=raptor_new_xml_writer(NULL,
                                                           uri_handler, uri_context,
                                                           rss_element->iostream,
-                                                          raptor_parser_simple_error, rdf_parser,
+                                                          (raptor_simple_message_handler)raptor_parser_simple_error, rdf_parser,
                                                           1);
             raptor_xml_writer_set_feature(rss_element->xml_writer, 
                                           RAPTOR_FEATURE_WRITER_XML_DECLARATION, 0);
@@ -551,7 +551,9 @@ raptor_rss_end_element_handler(void *user_data,
 {
   raptor_parser* rdf_parser;
   raptor_rss_parser* rss_parser;
+#ifdef RAPTOR_DEBUG
   const unsigned char* name=raptor_xml_element_get_name(xml_element)->local_name;
+#endif
   raptor_rss_element* rss_element;
   size_t cdata_len=0;
   unsigned char* cdata=NULL;
@@ -741,7 +743,7 @@ raptor_rss_insert_enclosure_identifiers(raptor_parser* rdf_parser,
     identifier->uri_source=RAPTOR_URI_SOURCE_URI;
   } else { 
     /* emit as blank node */
-    identifier->id=raptor_generate_id(rdf_parser, 0, NULL);
+    identifier->id=raptor_parser_internal_generate_id(rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL);
     identifier->type=RAPTOR_IDENTIFIER_TYPE_ANONYMOUS;
     identifier->uri_source=RAPTOR_URI_SOURCE_GENERATED;
   }
@@ -802,7 +804,7 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
       
         if(!identifier->uri) {
           /* need to make bnode */
-          identifier->id=raptor_generate_id(rdf_parser, 0, NULL);
+          identifier->id=raptor_parser_internal_generate_id(rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL);
           identifier->type=RAPTOR_IDENTIFIER_TYPE_ANONYMOUS;
           identifier->uri_source=RAPTOR_URI_SOURCE_GENERATED;
         }
@@ -843,7 +845,7 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
         }
       } else {
         /* need to make bnode */
-        identifier->id=raptor_generate_id(rdf_parser, 0, NULL);
+        identifier->id=raptor_parser_internal_generate_id(rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL);
         identifier->type=RAPTOR_IDENTIFIER_TYPE_ANONYMOUS;
         identifier->uri_source=RAPTOR_URI_SOURCE_GENERATED;
       }
@@ -1084,7 +1086,7 @@ raptor_rss_emit(raptor_parser* rdf_parser)
     /* make a new genid for the <rdf:Seq> node */
     items=raptor_new_identifier(RAPTOR_IDENTIFIER_TYPE_ANONYMOUS,
                                 NULL, RAPTOR_URI_SOURCE_GENERATED,
-                                (const unsigned char*)raptor_generate_id(rdf_parser, 0, NULL),
+                                (const unsigned char*)raptor_parser_internal_generate_id(rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL),
                                 NULL, NULL, NULL);
   
     /* _:genid1 rdf:type rdf:Seq . */
