@@ -87,7 +87,7 @@ raptor_rdfxml_serialize_init(raptor_serializer* serializer, const char *name)
   
   raptor_uri_get_handler(&uri_handler, &uri_context);
   context->nstack=raptor_new_namespaces(uri_handler, uri_context,
-                                        raptor_serializer_simple_error,
+                                        (raptor_simple_message_handler)raptor_serializer_simple_error,
                                         serializer,
                                         1);
   context->rdf_nspace=raptor_new_namespace(context->nstack,
@@ -213,10 +213,13 @@ raptor_rdfxml_serialize_start(raptor_serializer* serializer)
 
   raptor_uri_get_handler(&uri_handler, &uri_context);
 
+  if(context->xml_writer)
+    raptor_free_xml_writer(context->xml_writer);
+
   xml_writer=raptor_new_xml_writer(context->nstack,
                                    uri_handler, uri_context,
                                    serializer->iostream,
-                                   raptor_serializer_simple_error,
+                                   (raptor_simple_message_handler)raptor_serializer_simple_error,
                                    serializer,
                                    1);
   raptor_xml_writer_set_feature(xml_writer, RAPTOR_FEATURE_WRITER_XML_VERSION,
@@ -299,7 +302,8 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
     predicate_ns=context->rdf_nspace;
     sprintf((char*)ordinal_name, "_%d", *((int*)statement->predicate));
     name=ordinal_name;
-  } else {
+  } else if((statement->predicate_type == RAPTOR_IDENTIFIER_TYPE_PREDICATE) ||
+     (statement->predicate_type == RAPTOR_IDENTIFIER_TYPE_RESOURCE)) {
     unsigned char *p;
     size_t uri_len;
     size_t name_len=1;
@@ -336,6 +340,9 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
       free_predicate_ns=1;
     }
     raptor_free_uri(predicate_ns_uri);
+  } else {
+    raptor_serializer_error(serializer, "Cannot serialize a triple with subject node type %d\n", statement->predicate_type);
+    return 1;
   }
 
   
@@ -379,13 +386,15 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
       
       break;
       
-    case RAPTOR_IDENTIFIER_TYPE_PREDICATE:
     case RAPTOR_IDENTIFIER_TYPE_LITERAL:
     case RAPTOR_IDENTIFIER_TYPE_XML_LITERAL:
-
+      raptor_serializer_error(serializer, "Cannot serialize a triple with a literal subject\n");
+      break;
+      
+    case RAPTOR_IDENTIFIER_TYPE_PREDICATE:
     case RAPTOR_IDENTIFIER_TYPE_UNKNOWN:
     default:
-      raptor_serializer_error(serializer, "Do not know how to serialize node type %d\n", statement->subject_type);
+      raptor_serializer_error(serializer, "Cannot serialize a triple with subject node type %d\n", statement->subject_type);
   }
 
   if(attrs_count)
@@ -423,7 +432,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
         attrs[attrs_count++]=raptor_new_qname(context->nstack,
                                               (unsigned char*)"xml:lang",
                                               (unsigned char*)statement->object_literal_language,
-                                              raptor_serializer_simple_error,
+                                              (raptor_simple_message_handler)raptor_serializer_simple_error,
                                               serializer);
 
       len=strlen((const char*)statement->object);
@@ -504,7 +513,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
     case RAPTOR_IDENTIFIER_TYPE_PREDICATE:
     case RAPTOR_IDENTIFIER_TYPE_UNKNOWN:
     default:
-      raptor_serializer_error(serializer, "Do not know how to serialize node type %d\n", object_type);
+      raptor_serializer_error(serializer, "Cannot serialize a triple with object node type %d\n", object_type);
   }
 
   raptor_free_xml_element(predicate_element);
