@@ -753,7 +753,7 @@ raptor_xml_writer_comment_counted(raptor_xml_writer* xml_writer,
  *
  * Get list of xml_writer features.
  * 
- * If uri is not NULL, a pointer toa new raptor_uri is returned
+ * If uri is not NULL, a pointer to a new raptor_uri is returned
  * that must be freed by the caller with raptor_free_uri().
  *
  * Return value: 0 on success, <0 on failure, >0 if feature is unknown
@@ -826,10 +826,21 @@ raptor_xml_writer_set_feature(raptor_xml_writer *xml_writer,
     case RAPTOR_FEATURE_WARN_OTHER_PARSETYPES:
     case RAPTOR_FEATURE_CHECK_RDF_ID:
 
+    /* Shared */
+    case RAPTOR_FEATURE_NO_NET:
+
     /* XML writer features */
     case RAPTOR_FEATURE_RELATIVE_URIS:
     case RAPTOR_FEATURE_START_URI:
 
+    /* DOT serializer features */
+    case RAPTOR_FEATURE_RESOURCE_BORDER:
+    case RAPTOR_FEATURE_LITERAL_BORDER:
+    case RAPTOR_FEATURE_BNODE_BORDER:
+    case RAPTOR_FEATURE_RESOURCE_FILL:
+    case RAPTOR_FEATURE_LITERAL_FILL:
+    case RAPTOR_FEATURE_BNODE_FILL:
+
     default:
       return -1;
       break;
@@ -918,10 +929,21 @@ raptor_xml_writer_get_feature(raptor_xml_writer *xml_writer,
     case RAPTOR_FEATURE_WARN_OTHER_PARSETYPES:
     case RAPTOR_FEATURE_CHECK_RDF_ID:
 
+    /* Shared */
+    case RAPTOR_FEATURE_NO_NET:
+
     /* XML writer features */
     case RAPTOR_FEATURE_RELATIVE_URIS:
     case RAPTOR_FEATURE_START_URI:
 
+    /* DOT serializer features */
+    case RAPTOR_FEATURE_RESOURCE_BORDER:
+    case RAPTOR_FEATURE_LITERAL_BORDER:
+    case RAPTOR_FEATURE_BNODE_BORDER:
+    case RAPTOR_FEATURE_RESOURCE_FILL:
+    case RAPTOR_FEATURE_LITERAL_FILL:
+    case RAPTOR_FEATURE_BNODE_FILL:
+
     default:
       break;
   }
@@ -980,12 +1002,12 @@ main(int argc, char *argv[])
   raptor_uri* base_uri_copy=NULL;
 
   /* for raptor_new_iostream_to_string */
-  char *string=NULL;
+  void *string=NULL;
   size_t string_len=0;
 
   raptor_init();
   
-  iostr=raptor_new_iostream_to_string((void**)&string, &string_len, NULL);
+  iostr=raptor_new_iostream_to_string(&string, &string_len, NULL);
   if(!iostr) {
     fprintf(stderr, "%s: Failed to create iostream to string\n", program);
     exit(1);
