@@ -239,7 +239,7 @@ typedef union YYSTYPE
   int integer; /* 0+ for a xsd:integer datatyped RDF literal */
   double floating;
 }
-/* Line 193 of yacc.c.  */
+/* Line 187 of yacc.c.  */
 #line 244 "turtle_parser.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -2137,7 +2137,7 @@ yyreduce:
 #if RAPTOR_DEBUG > 1  
   printf("subject blank=\"%s\"\n", (yyvsp[(1) - (1)].string));
 #endif
-  id=raptor_generate_id((raptor_parser*)rdf_parser, 0, (yyvsp[(1) - (1)].string));
+  id=raptor_parser_internal_generate_id((raptor_parser*)rdf_parser, RAPTOR_GENID_TYPE_BNODEID, (yyvsp[(1) - (1)].string));
 
   (yyval.identifier)=raptor_new_identifier(RAPTOR_IDENTIFIER_TYPE_ANONYMOUS, NULL, RAPTOR_URI_SOURCE_BLANK_ID, id, NULL, NULL, NULL);
 }
@@ -2147,7 +2147,7 @@ yyreduce:
 #line 731 "./turtle_parser.y"
     {
   int i;
-  const unsigned char *id=raptor_generate_id((raptor_parser*)rdf_parser, 0, NULL);
+  const unsigned char *id=raptor_parser_internal_generate_id((raptor_parser*)rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL);
   
   (yyval.identifier)=raptor_new_identifier(RAPTOR_IDENTIFIER_TYPE_ANONYMOUS, NULL, RAPTOR_URI_SOURCE_GENERATED, id, NULL, NULL, NULL);
 
@@ -2223,7 +2223,7 @@ yyreduce:
 
   for(i=raptor_sequence_size((yyvsp[(2) - (3)].sequence))-1; i>=0; i--) {
     raptor_triple* t2=(raptor_triple*)raptor_sequence_get_at((yyvsp[(2) - (3)].sequence), i);
-    const unsigned char *blank_id=raptor_generate_id((raptor_parser*)rdf_parser, 0, NULL);
+    const unsigned char *blank_id=raptor_parser_internal_generate_id((raptor_parser*)rdf_parser, RAPTOR_GENID_TYPE_BNODEID, NULL);
     raptor_identifier* blank=raptor_new_identifier(RAPTOR_IDENTIFIER_TYPE_ANONYMOUS, NULL, RAPTOR_URI_SOURCE_GENERATED, blank_id, NULL, NULL, NULL);
     raptor_identifier* temp;
     
@@ -2598,7 +2598,7 @@ turtle_qname_to_uri(raptor_parser *rdf_parser, unsigned char *name, size_t name_
 
   return raptor_qname_string_to_uri(&turtle_parser->namespaces,
                                     name, name_len,
-                                    raptor_parser_simple_error, rdf_parser);
+                                    (raptor_simple_message_handler)raptor_parser_simple_error, rdf_parser);
 }
 
 
@@ -2642,7 +2642,7 @@ raptor_turtle_parse_init(raptor_parser* rdf_parser, const char *name) {
 
   raptor_namespaces_init(&turtle_parser->namespaces,
                          uri_handler, uri_context,
-                         raptor_parser_simple_error, rdf_parser, 
+                         (raptor_simple_message_handler)raptor_parser_simple_error, rdf_parser, 
                          0);
 
   turtle_parser->nil_uri=raptor_new_uri_for_rdf_concept("nil");
