@@ -53,17 +53,17 @@ extern "C" {
 /* does libxml struct xmlEntity have a field name_length */
 /*#define RAPTOR_LIBXML_ENTITY_NAME_LENGTH*/
 
-/* does libxml have xmlSAX2InternalSubset */
-#define RAPTOR_LIBXML_XMLSAX2INTERNALSUBSET
+/* Define to 1 if you have the `xmlCtxtUseOptions' function. */
+#define HAVE_XMLCTXTUSEOPTIONS 1
+
+/* Define to 1 if you have the `xmlSAX2InternalSubset' function. */
+#define HAVE_XMLSAX2INTERNALSUBSET 1
 
 /* does libxml xmlSAXHandler have externalSubset field */
 /*#define RAPTOR_LIBXML_XMLSAXHANDLER_EXTERNALSUBSET*/
 
 /* does libxml xmlSAXHandler have initialized field */
 /*#define RAPTOR_LIBXML_XMLSAXHANDLER_INITIALIZED*/
-
-/* does libxml have xmlUseNewParser */
-/*#define RAPTOR_LIBXML_XMLUSENEWPARSER*/
 #endif
 
 #define HAVE_STRICMP 1
@@ -90,7 +90,7 @@ extern "C" {
  */
 
 /* Release version as a decimal */
-#define RAPTOR_VERSION_DECIMAL 10412
+#define RAPTOR_VERSION_DECIMAL 10414
 
 /* Major version number */
 #define RAPTOR_VERSION_MAJOR 1
@@ -99,10 +99,10 @@ extern "C" {
 #define RAPTOR_VERSION_MINOR 4
 
 /* Release version number */
-#define RAPTOR_VERSION_RELEASE 12
+#define RAPTOR_VERSION_RELEASE 14
 
 /* Version number of package */
-#define VERSION "1.4.12"
+#define VERSION "1.4.14"
 
 
 #ifdef RAPTOR_XML_LIBXML
