@@ -310,7 +310,7 @@ main(int argc, char *argv[])
             int i;
             
             fprintf(stderr, "%s: Valid parser features are:\n", program);
-            for(i=0; i < raptor_get_feature_count(); i++) {
+            for(i=0; i < (int)raptor_get_feature_count(); i++) {
               const char *feature_name;
               const char *feature_label;
               if(!raptor_features_enumerate((raptor_feature)i, &feature_name, NULL, &feature_label)) {
@@ -320,7 +320,7 @@ main(int argc, char *argv[])
               }
             }
             fprintf(stderr, "%s: Valid serializer features are:\n", program);
-            for(i=0; i < raptor_get_feature_count(); i++) {
+            for(i=0; i < (int)raptor_get_feature_count(); i++) {
               const char *feature_name;
               const char *feature_label;
               if(!raptor_serializer_features_enumerate((raptor_feature)i, &feature_name, NULL, &feature_label)) {
@@ -333,7 +333,6 @@ main(int argc, char *argv[])
             fputs("\nA feature of the form xmlns:PREFIX=\"URI\" can be used to declare output\nnamespace prefixes and names for serializing using an XML-style syntax\nEither or both of PREFIX or URI can be omitted such as -f xmlns=\"URI\"\nThis form can be repeated for multiple declarations.\n", stderr);
 
             raptor_finish();
-
             exit(0);
           } else if(!strncmp(optarg, "xmlns", 5)) {
             struct namespace_decl *nd;
@@ -344,6 +343,8 @@ main(int argc, char *argv[])
               fprintf(stderr, "%s: Bad xmlns syntax in '%s'\n", program, 
                       optarg);
               rdfdump_free_namespace_decl(nd);
+
+              raptor_finish();
               exit(0);
             }
 
@@ -355,7 +356,7 @@ main(int argc, char *argv[])
             int i;
             size_t arg_len=strlen(optarg);
             
-            for(i=0; i < raptor_get_feature_count(); i++) {
+            for(i=0; i < (int)raptor_get_feature_count(); i++) {
               const char *feature_name;
               size_t len;
               
@@ -379,7 +380,7 @@ main(int argc, char *argv[])
               }
             }
             
-            for(i=0; i < raptor_get_feature_count(); i++) {
+            for(i=0; i < (int)raptor_get_feature_count(); i++) {
               const char *feature_name;
               size_t len;
               
@@ -513,7 +514,6 @@ main(int argc, char *argv[])
         fputc('\n', stdout);
 
         raptor_finish();
-
         exit(0);
 
 #ifdef SHOW_NAMESPACES_FLAG
@@ -534,23 +534,34 @@ main(int argc, char *argv[])
   if(usage) {
     if(usage>1) {
       fprintf(stderr, title_format_string, raptor_version_string);
-      fputs(raptor_short_copyright_string, stderr);
+      fputs("Raptor home page: ", stderr);
+      fputs(raptor_home_url_string, stderr);
       fputc('\n', stderr);
+      fputs(raptor_copyright_string, stderr);
+      fputs("\nLicense: ", stderr);
+      fputs(raptor_license_string, stderr);
+      fputs("\n\n", stderr);
     }
     fprintf(stderr, "Try `%s " HELP_ARG(h, help) "' for more information.\n",
                     program);
-    raptor_finish();
 
+    raptor_finish();
     exit(1);
   }
 
   if(help) {
     int i;
     
-    printf("Usage: %s [OPTIONS] <source URI> [base URI]\n", program);
     printf(title_format_string, raptor_version_string);
-    puts(raptor_short_copyright_string);
     puts("Parse RDF content at the source URI into RDF triples.");
+    printf("Usage: %s [OPTIONS] <source URI> [base URI]\n\n", program);
+
+    fputs(raptor_copyright_string, stdout);
+    fputs("\nLicense: ", stdout);
+    puts(raptor_license_string);
+    fputs("Raptor home page: ", stdout);
+    puts(raptor_home_url_string);
+
     puts("\nSyntax options:");
     puts(HELP_TEXT("i FORMAT", "input FORMAT ", "Set the input format to one of:"));
     for(i=0; 1; i++) {
@@ -558,19 +569,20 @@ main(int argc, char *argv[])
       const char *help_label;
       if(raptor_syntaxes_enumerate(i, &help_name, &help_label, NULL, NULL))
         break;
-      printf("    %-14s          %s", help_name, help_label);
+      printf("    %-14s  %s", help_name, help_label);
       if(!i)
         puts(" (default)");
       else
         putchar('\n');
     }
+    putchar('\n');
     puts(HELP_TEXT("o FORMAT", "output FORMAT", "Set the output format to one of:"));
     for(i=0; 1; i++) {
       const char *help_name;
       const char *help_label;
       if(raptor_serializers_enumerate(i, &help_name, &help_label, NULL, NULL))
         break;
-      printf("    %-14s          %s", help_name, help_label);
+      printf("    %-14s  %s", help_name, help_label);
       if(!i)
         puts(" (default)");
       else
@@ -592,10 +604,8 @@ main(int argc, char *argv[])
     puts(HELP_TEXT("w", "ignore-warnings ", "Ignore warning messages"));
     puts(HELP_TEXT("v", "version         ", "Print the Raptor version"));
     puts("\nReport bugs to http://bugs.librdf.org/");
-    puts("Raptor home page: http://librdf.org/raptor/");
 
     raptor_finish();
-
     exit(0);
   }
 
